@@ -19,14 +19,14 @@
 #ifndef AISLERIOT_BOARD_H
 #define AISLERIOT_BOARD_H
 
-#include <gtk/gtk.h>
-
-#ifdef HAVE_CLUTTER
-#include <clutter-gtk/clutter-gtk.h>
+#ifndef HAVE_CLUTTER
+#error board.h requires clutter
 #endif
 
-#include <libgames-support/games-card-theme.h>
+#include <clutter/clutter.h>
 
+#include "ar-style.h"
+#include "ar-cursor.h"
 #include "game.h"
 
 G_BEGIN_DECLS
@@ -43,52 +43,53 @@ typedef struct _AisleriotBoardPrivate	AisleriotBoardPrivate;
 typedef struct _AisleriotBoardClass	AisleriotBoardClass;
 
 struct _AisleriotBoard {
-#ifdef HAVE_CLUTTER
-  GtkClutterEmbed parent_instance;
-#else
-  GtkDrawingArea parent_instance;
-#endif
+  ClutterGroup parent_instance;
 
   /*< private >*/
   AisleriotBoardPrivate *priv;
 };
 
 struct _AisleriotBoardClass {
-#ifdef HAVE_CLUTTER
-  GtkClutterEmbedClass parent_class;
-#else
-  GtkDrawingAreaClass parent_class;
-#endif
+  ClutterGroupClass parent_class;
+
+  void (* request_cursor)   (AisleriotBoard *board,
+                             ArCursorType cursor_type);
+
+  void (* error_bell)       (AisleriotBoard *board);
+
+  /* Focus */
+  gboolean (* focus)        (AisleriotBoard *,
+                             int direction);
 
   /* keybinding signals */
-  gboolean (* move_cursor)  (AisleriotBoard *board,
-                             GtkMovementStep step,
-                             int count);
-  void (* activate)         (AisleriotBoard *board);
-  void (* toggle_selection) (AisleriotBoard *board);
-  void (* select_all)       (AisleriotBoard *board);
-  void (* deselect_all)     (AisleriotBoard *board);
+  gboolean (* move_cursor)  (AisleriotBoard *,
+                             const char *,
+                             guint,
+                             ClutterModifierType);
+  void (* activate)         (AisleriotBoard *,
+                             const char *,
+                             guint,
+                             ClutterModifierType);
+  void (* toggle_selection) (AisleriotBoard *,
+                             const char *,
+                             guint,
+                             ClutterModifierType);
+  void (* select_all)       (AisleriotBoard *,
+                             const char *,
+                             guint,
+                             ClutterModifierType);
+  void (* deselect_all)     (AisleriotBoard *,
+                             const char *,
+                             guint,
+                             ClutterModifierType);
 };
 
 GType aisleriot_board_get_type (void);
 
-GtkWidget *aisleriot_board_new (AisleriotGame *game);
+ClutterActor *aisleriot_board_new (ArStyle *style,
+                                   AisleriotGame *game);
 
-void aisleriot_board_set_card_theme (AisleriotBoard * board,
-                                     GamesCardTheme *theme);
-
-GamesCardTheme *aisleriot_board_get_card_theme (AisleriotBoard * board);
-
-void aisleriot_board_set_click_to_move (AisleriotBoard * board,
-                                        gboolean click_to_move);
-
-void aisleriot_board_set_animation_mode (AisleriotBoard *board,
-                                         gboolean enable);
-
-void aisleriot_board_abort_move (AisleriotBoard * board);
-
-void aisleriot_board_set_pixbuf_drawing (AisleriotBoard * board,
-                                         gboolean use_pixbuf_drawing);
+void aisleriot_board_abort_move (AisleriotBoard *board);
 
 G_END_DECLS
 
